# tf-mdp [![Build Status](https://travis-ci.org/thiagopbueno/tf-mdp.svg?branch=master)](https://travis-ci.org/thiagopbueno/tf-mdp) [![License](https://img.shields.io/aur/license/yaourt.svg)](https://github.com/thiagopbueno/tf-mdp/blob/master/LICENSE)

Probabilistic planning in continuous state-action MDPs using TensorFlow.
